@@ -12,7 +12,8 @@ def evaluate_model():
     with open("model_params.yml") as f:
         params = yaml.safe_load(f)
 
-    test_df = pd.read_csv("data/processed/test.csv")[:25]
+    test_df = pd.read_csv("data/processed/test.csv")
+    test_df = test_df.sample(n=25, random_state=42)
     model = Summarization()
     model.load_model(model_type=params["model_type"], model_dir=params["model_dir"])
     results = model.evaluate(test_df=test_df, metrics=params["metric"])
